@@ -7,7 +7,7 @@ from .settings import LayoutSettings
 from .notes import Notes
 from .export_html import _HhtmlExporter
 from .intro import key_combs
-from ..formatters import _HTML
+from ..formatters import XTML
 from ..xmd import _special_funcs
 
 class BaseSlides:
@@ -100,7 +100,7 @@ class BaseSlides:
     @property
     def xmd_syntax(self):
         "Special syntax for markdown."
-        return _HTML(self.parse(textwrap.dedent('''
+        return XTML(self.parse(textwrap.dedent('''
         ## Extended Markdown
         Extended syntax for markdown is constructed to support almost full presentation from Markdown.
         
@@ -112,6 +112,7 @@ class BaseSlides:
         - alert`section\`key\`` to add a section that will appear in the table of contents.
         - alert`toc\`Table of content header text\`` to add a table of contents. Run at last again to collect all.
         - alert`proxy\`placeholder text\`` to add a proxy that can be updated later with `Slides.proxies[index].capture` contextmanager. Useful to keep placeholders for plots in markdwon.
+        - alert`peoxy\`[Button Text]\`` to add a proxy that can be replaced by pasting image from clipboard later.
         - Triple dashes `---` is used to split markdown text in slides inside `from_markdown(start, file_or_str)` function.
         - Double dashes `--` is used to split markdown text in frames.
         
@@ -202,7 +203,7 @@ class BaseSlides:
             - Do not use this to change global state of slides, because that will affect all slides.
             - This can be used single time per slide, overwriting previous function.
         """
-        for name in ['write','print','display']:
+        for name in ['write','print','display','alt']:
             if name in func.__code__.co_names:
                 self._warnings.append(f'UserWarning: Output of `{name}` function under `on_load` may be lost while presenting. I hope you know what you are doing!')
         
@@ -382,7 +383,8 @@ class BaseSlides:
         auto.from_markdown('section`Introduction` toc`### Contents`')
             
         with auto.slide():
-            self.write(['# Main App',self.doc(Slides)])
+            self.write(['# Main App',self.doc(Slides), '### Jump between slides'])
+            self.doc(self.goto_button, 'Slides').display()
         
         with auto.slide():
             self.write('## Adding Slides section`Adding Slides and Content`')
@@ -394,15 +396,15 @@ class BaseSlides:
             
         with auto.slide():
             self.write('## Adding Content')
-            self.write('Besides functions below, you can add content to slides with `%%xmd`,`%xmd`, `display(obj)` as well.\n{.note .info}')
+            self.write('Besides functions below, you can add content to slides with `%%xmd`,`%xmd` as well.\n{.note .info}')
             self.write([self.classed(self.doc(self.write,'Slides'),'block-green'), self.doc(self.parse,'Slides'),self.doc(self.cite,'Slides'),self.doc(self.clipboard_image,'Slides')])
         
         with auto.slide():
             self.write('## Adding Speaker Notes')
+            (skipper := self.goto_button('Skip to Dynamic Content')).display()
             self.write([f'You can use alert`notes\`notes content\`` in markdown.\n{{.note .success}}\n',
                        'This is experimental feature, and may not work as expected.\n{.note-error .error}'])
             self.doc(self.notes,'Slides.notes', members = True, itself = False).display()
-            self.goto_button(10,'Jump to Slide 10', 'This is kind a alert`alt text` because button will alert`NOT` show in screenshot of slides')
                    
         with auto.slide():
             self.write('## Displaying Source Code')
@@ -416,14 +418,17 @@ class BaseSlides:
                 
         with auto.slide():
             self.write('## Useful Functions for Rich Content section`?Useful Functions for alert`Rich Content`?`')
-            members = ['alt', 'alert','block', 'bokeh2html', 'bullets','cite','classed',
+            self.doc(self.clipboard_image,'Slides').display()
+            self.run_doc(self.alt,'Slides')
+            
+            members = ['alert','block', 'bokeh2html', 'bullets','cite','classed',
                        'color', 'cols', 'details', 'doc','sub','sup', 'today', 'enable_zoom', 'format_css', 'highlight',
                        'html', 'iframe', 'image', 'keep_format', 'notify', 'plt2html', 'raw', 'rows',
                         'section', 'set_citations', 'set_dir', 'sig', 'textbox', 'suppress_output','suppress_stdout','svg', 'vspace']
-            self.doc(self.clipboard_image,'Slides').display()
             self.doc(self, 'Slides', members = members, itself = False).display()
             
         with auto.slide() as s:
+            skipper.set_target() # Set target for skip button
             self.write('## Dynamic Content')
             self.run_doc(self.on_refresh,'Slides')
             self.run_doc(self.on_load,'Slides')
@@ -467,8 +472,13 @@ class BaseSlides:
         
         auto.from_markdown('section`Advanced Functionality` toc`### Contents`')
         
-        with auto.slide():
+        with auto.slide() as s:
             self.write('## Adding User defined Objects/Markdown Extensions')
+            self.write(
+                lambda: display(self.html('h3','I will be on main slides',className='warning'), 
+                metadata = {'text/html': '<h3 class="warning">I will be on exported slides/report</h3>'}), # Can also do 'Slides.serilaizer.get_metadata(obj)' if registered
+                s.get_source(), widths = [1,3]
+            )
             self.write('If you need to serialize your own or third party objects not serialized by this module, you can use `@Slides.serializer.register` to serialize them to html.\n{.note .info}')
             self.doc(self.serializer,'Slides.serializer', members = True, itself = False).display()
             self.write('**You can also extend markdown syntax** using `markdown extensions`, ([See here](https://python-markdown.github.io/extensions/) and others to install, then use as below):')
