@@ -171,6 +171,7 @@ __theme_css__
 	scroll-snap-type: x mandatory !important;
     display: flex !important;
     overflow-x: auto !important;
+    overflow-y: hidden !important; 
     position: fixed !important;
     top: 0 !important;
     left: 0 !important;
@@ -180,15 +181,23 @@ __theme_css__
 section {
 	scroll-snap-align:start !important;
     scroll-snap-stop: always !important;
-	display: flex !important;
+	display: block !important;
 	height: 100vh !important;
 	max-height: 100vh !important;
 	min-width: 100vw !important;
 	box-sizing: border-box !important;
 }
+section .SlideBox {
+    width: 100vw !important;
+    height: 100vh !important; 
+    display: flex !important;
+    flex-direction: column !important;
+    box-sizing: border-box !important;
+}
+section .SlideBox > .Footer > .Progress { display: none !important; }
 section .SlideArea {
 	height: auto !important;
-	max-height: 100vh !important;
+	max-height: calc(100vh - 20px) !important; /* 20px for footer */ 
 	box-sizing: border-box;
 	overflow-y: auto !important;
 	width: 90vw !important;
@@ -196,13 +205,11 @@ section .SlideArea {
 	padding: 1em !important;
     box-sizing: border-box !important;
 }
-section span.html-slide-number {
-    width: auto;
-    height: 1.3em;
-    padding: 0.1em;
-    margin: auto 8px 8px auto;
-    color: var(--secondary-fg);
+section .SlideBox > .Footer { background: var(--primary-bg) !important;}
+section .SlideBox > .Footer > p {
     font-size: 14px !important;
+    padding: 4px !important;
+    padding-left: 8px !important;
 }
 .SlidesWrapper::-webkit-scrollbar:vertical,
 .SlidesWrapper::-webkit-scrollbar-button,
@@ -217,6 +224,19 @@ section span.html-slide-number {
 .SlidesWrapper::-webkit-scrollbar-track-piece:start {
     background-color: var(--accent-color, navy) !important;
 }
+a.goto-button {
+    padding: 6px;
+    border: 1px solid var(--accent-color);
+    border-radius: 6px;
+    font-size: 16px;
+}
+a.goto-button:hover, a.goto-button:focus {
+    box-shadow: 2px 2px 4px var(--secondary-bg);
+    background: var(--secondary-bg);
+}
+a.goto-button:active {
+    color: var(--pointer-color);
+}
 
 @media print {
     * {
@@ -225,7 +245,7 @@ section span.html-slide-number {
         color-adjust: exact !important;
     }
     @page {
-        size: letter landscape;
+        size: 297mm __HEIGHT__; /* A4 is 297mm x decided by aspect_ratio by user*/
         margin-top: 0 !important;
         margin-right: 0 !important;
         margin-left: 0 !important;
@@ -242,7 +262,7 @@ section span.html-slide-number {
         height: auto !important;
     }
     section {
-        display: flex !important;
+        display: block !important;
         margin: 0 !important;
         page-break-inside: avoid !important;
         page-break-after: always !important;
@@ -252,9 +272,18 @@ section span.html-slide-number {
     section:last-of-type {
         page-break-after: avoid !important;
     }
+    section:first-of-type .SlideBox > .Footer {display: none !important;} /* remove footer from title slide in print*/
+    section .SlideBox {
+        page-break-inside: avoid !important;
+    }
+    section .SlideBox > .Footer > .Progress { 
+        display: block !important; 
+        height: 4px !important;
+        width: 100% !important;
+    }
     section .SlideArea {
         height: auto !important;
-        max-height: 100% !important;
+        max-height: calc(100% - 20px) !important; /* 20px for footer */
         box-sizing: border-box;
         overflow: hidden !important;
         width: 90% !important;
