@@ -2,7 +2,7 @@
 
 import sys, time
 from contextlib import contextmanager
-from ipywidgets import Output, Layout, Button, HBox
+from ipywidgets import Output, Layout, Button, HBox, VBox, Label
 
 from IPython.display import display
 from IPython.utils.capture import capture_output
@@ -14,20 +14,24 @@ from ..utils import html, color, _format_css, _sub_doc, _css_docstring
 
 class _EmptyCaptured: outputs = [] # Just for initialization
 
-def _expand_cols(outputs, context):
-    "Put columns inline with rich outputs in a given context."
+def _expand_objs(outputs, context):
+    "Put columns and exportable widgets inline with rich outputs in a given context."
     new_outputs = []
     for out in outputs:
         if hasattr(out, 'metadata') and ('COLUMNS' in out.metadata): # may be Writer object there without metadata
             new_outputs.append(context._columns[out.metadata['COLUMNS']])
+        elif hasattr(out, 'metadata') and 'Exp4Widget' in out.metadata:
+            other_context = context if hasattr(context, '_exportables') else context._slide # Proxy also has exportables
+            new_outputs.append(other_context._exportables[out.metadata['Exp4Widget']])
         else:
             new_outputs.append(out)
     return new_outputs
+                    
 
 class DynamicRefresh:
     "DynamicRefresh is a display for a function that is executed when refresh button is clicked. Should not be instantiated directly."
     def __init__(self, func, slide):
-        if getattr(slide._app, '_in_dproxy', None): # raise this also because dictionary size get changed during iteration if nested
+        if slide._app.in_dproxy: # raise this also because dictionary size get changed during iteration if nested
             raise Exception('Dynamically refreshable content cannot be written inside another same type!')
         
         self._func = func
@@ -72,16 +76,16 @@ class DynamicRefresh:
         "Updates the display of the dynamic content."
         self._on_click(None)
     
-    def fmt_html(self, allow_non_html_repr = True): 
+    def fmt_html(self): 
         content = ''
         for out in self.outputs:
             if hasattr(out, 'fmt_html'): # Columns
-                content += out.fmt_html(allow_non_html_repr = allow_non_html_repr)
-            else:
-                if 'text/html' in out.data:
-                    content += out.data['text/html']
-                elif allow_non_html_repr:
-                    content += out.data['text/plain']
+                content += out.fmt_html()
+            elif hasattr(out, 'metadata') and isinstance(out.metadata, dict) and 'text/html' in out.metadata: # Should take precedence over data if given
+                content += out.metadata['text/html']
+            elif 'text/html' in out.data:
+                content += out.data['text/html']
+            
         return content
     
     @property
@@ -93,27 +97,26 @@ class DynamicRefresh:
     @property
     def outputs(self):
         "Executes given function and returns its output as list of outputs."
-        old = self._slide._app._running_slide
-        self._slide._app._running_slide = self._slide
         self._slide._app._in_dproxy = self
         self._columns = {} # Reset columns here just before executing function
-        try:
-            with capture_output() as captured:
-                self._func()
-                
-            self._last_outputs = _expand_cols(captured.outputs,self) # Expand columns is necessary
-            
-        except:
-            if self._raise_error:
-                wdgts = self.error_handler() # should capture outside
-                with capture_output() as err_captured:
-                    display(*wdgts)
-                    
-                self._error_outputs = err_captured.outputs
-                     
-        finally:
-            self._slide._app._running_slide = old # should go back
-            self._slide._app._in_dproxy = None
+        
+        with self._slide._app._set_running(self._slide): # Set running slide to this slide
+            try:
+                with capture_output() as captured:
+                    self._func()
+
+                self._last_outputs = _expand_objs(captured.outputs,self) # Expand columns is necessary
+
+            except:
+                if self._raise_error:
+                    wdgts = self.error_handler() # should capture outside
+                    with capture_output() as err_captured:
+                        display(*wdgts)
+
+                    self._error_outputs = err_captured.outputs
+
+            finally:
+                self._slide._app._in_dproxy = None
             
         if self._error_outputs: 
             return self._last_outputs + self._error_outputs
@@ -144,19 +147,53 @@ class DynamicRefresh:
 class Proxy:
     "Proxy object, should not be instantiated directly by user."
     def __init__(self, text, slide):
-        if getattr(slide._app, '_in_dproxy', None):
+        if slide._app.in_dproxy:
             raise RuntimeError("Can't place proxy inside a refreshable function.")
         
-        if getattr(slide._app, '_in_proxy', None):
+        if slide._app.in_proxy:
             raise RuntimeError("Can't place proxy inside another proxy being captured.")
         
-        self._text = text
         self._slide = slide
+        self._to_display = self
+        self._text = text.strip() # Remove leading and trailing spaces
+        
+        if self._text.startswith('[') and self._text.endswith(']'):
+            self._text = self._text[1:-1]
+            btn1 = Button(description = 'Paste', layout = Layout(width='auto'))
+            btn2 = Button(description = 'Paste for Export Only', layout = Layout(width='auto'))
+            btns = VBox([Label(f'Paste Proxy: "{self._text}"'), HBox([btn1, btn2])], layout = Layout(width='auto',border='1px solid var(--accent-color)')).add_class('ProxyPasteBtns')
+            self._to_display = btns
+            
+            def on_click(btn):
+                try:
+                    im = self._slide._app.clipboard_image(f'attachment:{id(self)}.png', overwrite = True).to_html()
+                        
+                    with self.capture(): # capture if successful above, otherwise don't
+                        display(self._to_display) # keep buttons there to replace later, won't be displayed in export
+                        if btn is btn1: 
+                            im.display()
+                            btn1.description = 'Replace ?'
+                            btn2.description = 'Paste for Export Only'
+                        elif btn is btn2:
+                            html('div', [im], className='export-only',style = '').display()
+                            btn2.description =  'Pasted for Export Only: Replace ?'
+                            btn1.description = 'Paste'
+                            
+                except: 
+                    self._slide._app.notify('No supported image on clipboard to paste!')
+                    
+            btn1.on_click(on_click)
+            btn2.on_click(on_click)
+        
         self._outputs = []
         self._key = str(len(self._slide._proxies))
         self._slide._proxies[self._key] = self
         self._columns = {} 
-        display(self, metadata= {'Proxy': self._key}) 
+        self._exportables = {}
+        display(self._to_display, metadata= {'Proxy': self._key}) 
+        
+    def _exp4widget(self, widget, func):
+        return Exp4Widget(widget, func, self)
     
     @property
     def text(self): return self._text # Useful if user wants to filter proxies
@@ -174,11 +211,23 @@ class Proxy:
     def outputs(self):
         "Returns the outputs of the proxy, if it has been replaced."
         if self._outputs:
-            return self._outputs
+            return self._outputs 
         with capture_output() as captured:
-            display(self, metadata= {'Proxy': self._key}) # This will update the slide refrence on each display to provide useful info
+            display(self._to_display, metadata= {'Proxy': self._key}) # This will update the slide refrence on each display to provide useful info
         return captured.outputs
     
+    def fmt_html(self): 
+        content = ''
+        for out in self.outputs:
+            if hasattr(out, 'fmt_html'): # Columns and others
+                content += out.fmt_html()
+            elif hasattr(out, 'metadata') and isinstance(out.metadata, dict) and 'text/html' in out.metadata: # Should take precedence over data if given
+                content += out.metadata['text/html']
+            elif 'text/html' in out.data:
+                content += out.data['text/html']
+            
+        return content
+    
     @contextmanager
     def capture(self):
         "Context manager to capture output to current prpxy. Use it like this: with proxy.capture(): ... after a slide is already created."
@@ -186,6 +235,7 @@ class Proxy:
             raise RuntimeError("Can't use Proxy.capture() contextmanager inside a slide constructor.")
         
         self._columns = {} # Reset columns
+        self._exportables = {} # Reset exportables
         self._slide._app._in_proxy = self # Used to get print statements to work in order and coulm aware
         try:
             with capture_output() as captured:
@@ -194,10 +244,35 @@ class Proxy:
             if captured.stderr:
                 raise RuntimeError(captured.stderr)
 
-            self._outputs = _expand_cols(captured.outputs, self) # Expand columns
+            self._outputs = _expand_objs(captured.outputs, self) # Expand columns
             self._slide.update_display() # Update display to show new output
         finally:
             self._slide._app._in_proxy = None
+            
+class Exp4Widget:
+    def __init__(self, widget, func, context):
+        if not isinstance(context, (Slide, Proxy)):
+            raise TypeError("context should be a Slide or Proxy object.")
+        
+        self._widget = widget
+        self._func = func 
+        self._context = context # Should be slide or proxy
+        self._key = str(len(self._context._exportables))
+        self._context._exportables[self._key] = self # Add to exportables
+    
+    def _ipython_display_(self):
+        display(self._widget, metadata= self.metadata)
+    
+    @property
+    def metadata(self): return {'Exp4Widget': self._key} # Important
+    
+    @property
+    def data(self): return getattr(self._widget, '_repr_mimebundle_', lambda: {'application':'Exp4Widget'})()
+    
+    def fmt_html(self,**kwargs): # kwargs should be there to be similar to other fmt_html methods
+        "Returns alternative html representation of the widget."
+        return self._func(self._widget)
+    
 
 class Slide:
     "Slide object, should not be instantiated directly by user."
@@ -222,7 +297,11 @@ class Slide:
         self._section = None # Added from Slides
         self._proxies = {} # Placeholders added to this slide
         self._dproxies = {} # Dynamic placeholders added to this slide
+        self._exportables = {} # Exportable widgets added to this slide
         self._columns = {} # Columns added to this slide
+        
+    def _exp4widget(self, widget, func):
+        return Exp4Widget(widget, func, self)
   
     def set_source(self, text, language):
         "Set source code for this slide."
@@ -241,22 +320,21 @@ class Slide:
         return Proxy(text, self) # get auto displayed
         
     def _on_load_private(self, func):
-        old = self._app.running
-        self._app._running_slide = None # temporarily set it to None to avoid dynamic things inside on_load, as it will not be running on load
-        try: # check if code is correct
-            with capture_output():
-                func()
-        except Exception as e:
-            if 'constructor' in str(e):
-                raise RuntimeError(f'{e}\nYou may be trying to put dynamic content inside on_load which is restricted!')
-            raise e
-        finally:
-            self._app._running_slide = old
+        with self._app._hold_running(): # slides will not be running during switch, so make it safe
+            try: # check if code is correct
+                with capture_output():
+                    func()
+            except Exception as e:
+                if 'constructor' in str(e):
+                    raise RuntimeError(f'{e}\nYou may be trying to put dynamic content inside on_load which is restricted!')
+                raise e
+        
         # This should be outside the try/except block even after finally, if successful, only then assign it.
         self._on_load = func # This will be called in main app
     
     def run_on_load(self):
         "Called when a slide is loaded into view. Use it to register notifications etc."
+        self.get_footer(update_widget=True) # Update footer with latest slide
         self._widget.layout.height = '100%' # Trigger a height change to reset scroll position
         start = time.time()
         try: # Try is to handle errors in on_load, not for attribute errors, and also finally to reset height
@@ -273,7 +351,6 @@ class Slide:
     @contextmanager
     def _capture(self):
         "Capture output to this slide."
-        self._app._running_slide = self
         self._app._next_number = int(self._number) + 1
         self._notes = '' # Reset notes
         self._citations = {} # Reset citations
@@ -281,24 +358,25 @@ class Slide:
         self._proxies = {} # Reset placeholders
         self._dproxies = {} # Reset dynamic placeholders
         self._columns = {} # Reset columns
+        self._exportables = {} # Reset exportables
         if hasattr(self,'_on_load'):
             del self._on_load # Remove on_load function
+        if hasattr(self,'_target_id'):
+            del self._target_id # Remove target_id
         
-        try:
+        with self._app._set_running(self):
             self._app._remove_post_run_callback() # Remove before capturing
             with capture_output() as captured:
                 yield captured
-            
+
             if captured.stderr:
                 raise RuntimeError(f'Error in building {self}: {captured.stderr}')
-            
+
             # If no error, then add callback keeping the user preference
             if self._app._post_run_enabled:
                 self._app.shell.events.register('post_run_cell', self._app._post_run_cell)
-            
-        finally:
-            self._app._running_slide = None
-            self._contents = _expand_cols(captured.outputs, self) # Expand columns  
+
+            self._contents = _expand_objs(captured.outputs, self) # Expand columns  
         
         if self._app._warnings:
             print(*self._app._warnings, sep='\n\n')
@@ -335,6 +413,17 @@ class Slide:
         "Clear display of this slide."
         self._app._slidelabel = self.label # Go there to see effects
         self._widget.clear_output(wait = wait)
+    
+    def show(self):
+        "Show this slide in cell."
+        out = Output().add_class('SlideArea')
+        with out:
+            display(*self.contents)
+        return display(out)
+    
+    def get_footer(self, update_widget = False): # Used here and export_html
+        "Return footer of this slide. Optionally update footer widget."
+        return self._app.settings.get_footer(self, update_widget = update_widget)
         
     @property
     def frames(self):
@@ -390,7 +479,9 @@ class Slide:
     def contents(self):
         outputs = []
         for out in self._contents:
-            if 'DYNAMIC' in out.metadata:
+            if 'Exp4Widget' in out.metadata:
+                outputs.append(self._exportables[out.metadata['Exp4Widget']]) # This will get displayed as a widget
+            elif 'DYNAMIC' in out.metadata:
                 outputs.append(self._dproxies[out.metadata['DYNAMIC']]) # This will get displayed as a widget
             elif 'Proxy' in out.metadata:
                 outputs.extend(self._proxies[out.metadata['Proxy']].outputs) # replace Proxy with its outputs/or new updated slide information
