@@ -11,8 +11,8 @@ import ipywidgets as ipw
 
 from .xmd import parse, extender as _extender
 from .source import Source
-from .writer import write, iwrite
-from .formatters import bokeh2html, plt2html, highlight, _HTML, serializer, _fix_repr
+from .writer import GotoButton, write
+from .formatters import XTML, bokeh2html, plt2html, highlight, htmlize, serializer
 from . import utils
 
 _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
@@ -85,7 +85,6 @@ class Slides(BaseSlides):
         self.source = Source # Code source
         self.icon = _Icon # Icon is useful to add many places
         self.write  = write 
-        self.iwrite = iwrite
         self.parse = parse # Parse extended markdown
         self.serializer = serializer # Serialize IPython objects to HTML
         
@@ -134,8 +133,8 @@ class Slides(BaseSlides):
         self._max_index = 0 # Maximum index including frames
         self._running_slide = None # For Notes, citations etc in markdown, controlled in Slide class
         self._next_number = 0 # Auto numbering of slides should be only in python scripts
-        
         self._citations = {} # Initialize citations dictionary
+        
         with self.set_dir(self.assets_dir): # Set assets directory
             self._set_citations_from_file('citations.json') # Load citations from file if exists
         
@@ -151,6 +150,26 @@ class Slides(BaseSlides):
         self.set_overlay_url(url = None) # Set overlay url for initial information
         self._remove_post_run_callback() # Remove post_run_cell callback at end of init, otherwise it appears during import
     
+    
+    @contextmanager
+    def _set_running(self, slide):
+        "Context manager to set running slide and turns back to previous."
+        if slide and not isinstance(slide, Slide): # None is acceptable to hold running slide in other function
+            raise TypeError(f"slide must be None or Slide, got {type(slide)}")
+        
+        old = self.running
+        self._running_slide = slide
+        try:
+            yield
+        finally:
+            self._running_slide = old
+    
+    @contextmanager
+    def _hold_running(self):
+        "Context manager to pause running slide and restore it after"
+        with self._set_running(None):
+            yield
+    
     @contextmanager
     def skip_post_run_cell(self):
         """Context manager to skip post_run_cell event.""" 
@@ -261,6 +280,21 @@ class Slides(BaseSlides):
         "Access slide currently being built. Useful inside frames decorator."
         return self._running_slide
     
+    @property
+    def in_proxy(self):
+        "Check if proxy is capturing output."
+        return getattr(self, '_in_proxy', None)
+    
+    @property
+    def in_dproxy(self):
+        "Check if dynamic proxy is capturing output."
+        return getattr(self, '_in_dproxy', None)
+    
+    @property
+    def overlay_button(self):
+        "Get overlay button to reveal overlay easily from slide. Like opeing a drawer/demo notebook etc."
+        return self.widgets.toggles.overlay
+    
     def verify_running(self, error_msg = ''):
         "Verify if slide is being built, otherwise raise error."
         if self.running is None:
@@ -418,7 +452,7 @@ class Slides(BaseSlides):
                 sections.append(self.html('div', fmt_sec(self.running), style='',className='toc-item this'))
                 
             elif sections:
-                sections[-1] = _HTML(sections[-1].value.replace('toc-item prev','toc-item this'))
+                sections[-1] = XTML(sections[-1].value.replace('toc-item prev','toc-item this'))
 
             for slide in self[this_index+1:]:
                 if slide._section:
@@ -429,41 +463,46 @@ class Slides(BaseSlides):
         return self._dynamic_private(_toc_handler, tag = '_toced', hide_refresher = True)
         
     
-    def _goto_button(self, slide_number, text,text_before = '', extra_func=None, **kwargs):
-        "See docs of `goto_button`. This is internal function to return button box. extra_func is a function to be called on click after going to slide."
-        if not isinstance(slide_number, (int,float,str)): # keep string for internal use only
-            raise TypeError('Slide number should be an integer or float for accessing frames!')
+    def _goto_button(self, text, target_slide = None, _other_text = None, _extra_func=None, **kwargs):
+        if target_slide and not isinstance(target_slide, Slide):
+            raise TypeError(f'target_slide should be Slide, got {type(target_slide)}')
+        
+        kwargs['description'] = text # override description with text
+        button = ipw.Button(**kwargs).add_class('goto-button')
+        setattr(button, '_TargetSlide', target_slide) # Monkey patching target slide
         
-        button = ipw.Button(description=text,**kwargs).add_class('goto-button')
         def on_click(btn):
             try:
-                ss = str(slide_number)
-                if '.' in ss:
-                    s,f = ss.split('.')
-                    slide = self._slides_dict[s].frames[int(f)-1]
-                else:
-                    slide = self._slides_dict[ss]
-                
-                self.progress_slider.index = slide.index # let it throw error if slide does not exist
-                if callable(extra_func): # Call extra function if given after chnaging slides, no need for user
-                    extra_func()
+                self.progress_slider.index = btn._TargetSlide.index # let it throw error if slide does not exist before calling _extra_func
+                if callable(_extra_func): # Call extra function if given after chnaging slides, no need for user
+                    _extra_func()
                     
             except:
-                self.notify(f'Failed to jump to slide {slide_number!r}, it may not exist yet!')
+                self.notify(f'Failed to jump to slide {btn._TargetSlide.index!r}, you may have not used GotoButton.set_target() anywhere!')
 
         button.on_click(on_click)
         
-        html_before = ipw.HTML(_fix_repr(text_before)).add_class('goto-html')
-        return ipw.HBox([html_before,button],layout=ipw.Layout(align_items='center')).add_class('goto-box')
+        if _other_text is not None: # For TOC
+            html_before = ipw.HTML(htmlize(_other_text)).add_class('goto-html')
+            return ipw.HBox([html_before,button],layout=ipw.Layout(align_items='center')).add_class('goto-box')
+        
+        else: # For links in exported slides
+            return GotoButton(button,app = self)
     
-    def goto_button(self, slide_number, text,text_before = '', **kwargs):
-        """"Jump to slide_number when clicked. give slide_number as integer of float like 1, 3.1 etc.   
-        `text` is the text to be displayed on button.    
-        `text_before` additional text (will be parsed) on left of the Button. It is useful because button will not show up in sceenshot.        
-        `kwargs` are passed to `ipywidgets.Button` function.          
-        **Note:** This button has a CSS classes nested as 'goto-box' > ('goto-html','goto-button') 
-        that can be used to style it under each slide separately."""
-        return display(self._goto_button(slide_number, text,text_before = text_before, **kwargs))
+    def goto_button(self, text, **kwargs):
+        """"
+        Initialize a button to jump to given target slide when clicked. 
+        `text` is the text to be displayed on button. 
+        `kwargs` are passed to `ipywidgets.Button` function. 
+        
+        - Pass to write command or use `.display()` method to display button in a slide.
+        - Use `.set_target()` method under target slide.
+        
+        ::: note-tip        
+            - `goto_button` is converted to a link in exported slides that can be clicked to jump to slide.
+            - You can use `.set_target()` on a previous slides and `.display()` on a later slide to create a link that jumps backwards.
+        """
+        return self._goto_button(text, target_slide = None, _other_text = None, **kwargs)
         
     def show(self): 
         "Display Slides."
@@ -491,6 +530,7 @@ class Slides(BaseSlides):
     
     def __reset_navbox(self):
         "Reset navbox to add inview button for Jupyter Lab"
+        self.widgets.checks.postrun.disabled = False # Enable it
         others = [w for w in self.widgets.navbox.children if w is not self.widgets.buttons._inview]
         self.widgets.navbox.children = [self.widgets.buttons._inview, *others]
         
@@ -561,12 +601,9 @@ class Slides(BaseSlides):
         if self._iterable and change:
             self.notes._display(self.current.notes) # Display notes first
             self.widgets.htmls.toast.value = '' # clear notification content if any defined by on_load
-        
-            number = f'{self.current.label} / {self._nslides}' if self.current.label != '0' else ''
-            self.settings._update_footer(number_str = number) # Update footer privately
             
             self._switch_slide(old_index= change['old'], new_index= change['new']) 
-            self.current.run_on_load() # Run on_load setup after switching slide
+            self.current.run_on_load() # Run on_load setup after switching slide, it updates footer as well
            
             
     def refresh(self): 
@@ -602,6 +639,9 @@ class Slides(BaseSlides):
     def proxy(self,text):
         """Place a proxy placeholder in your slide and returns it's `handle`. This is useful when you want to update the placeholder later.
         Use `Slides.proxies[index].capture` or `handle.capture` contextmanager to update the placeholder.
+        ::: note-tip
+            - Use square brackets around text like `proxy('[Button Text]')` to create a button that can paste image from clipboard. This is useful to export screenshots of widgets in a given state.
+            - Show/hide the proxy buttons by a checkbox `Hide Proxy Buttons` in settings panel once you are done with pasting and ready to export/present.
         """
         self.verify_running('proxy placeholder can only be used in a slide constructor!')
         return self.running._proxy_private(text)
@@ -845,14 +885,13 @@ class Slides(BaseSlides):
         ]
         
         if not tocs_dict:
-            children.append(ipw.HTML(_fix_repr('No sections found!, create sections with alert`Slides.section` method'
+            children.append(ipw.HTML(htmlize('No sections found!, create sections with alert`Slides.section` method'
                     ' or alert`section\`key\``')))
         else:
             for i,(sec,slide) in enumerate(tocs_dict.items(), start = 1):
-                slide_number = f"{slide._number}.{slide._label.split('.')[1]}" if '.' in slide._label else slide._number
-                text_before = _fix_repr(f'color[var(--accent-color)]`{i}.` {sec}') + f"<p>{slide._label}</p>"
-                extra_func = lambda: self.widgets.buttons.toc.click()
-                p_btn = self._goto_button(slide_number,'', text_before= text_before,extra_func=extra_func)
+                _other_text = htmlize(f'color[var(--accent-color)]`{i}.` {sec}') + f"<p>{slide._label}</p>"
+                _extra_func = lambda: self.widgets.buttons.toc.click()
+                p_btn = self._goto_button('', target_slide = slide, _other_text = _other_text,_extra_func = _extra_func)
                 children.append(p_btn.add_class('toc-item').add_class(f's{slide._index}')) # class for dynamic CSS
                 
         self.widgets.tocbox.children = children
@@ -920,7 +959,7 @@ class Slides(BaseSlides):
             self.widgets.htmls.overlay.value= _html.value
                
             if self._called_from_notenook('set_overlay_url') and not getattr(self.current,'_on_load',None):
-                self.settings.btn_overlay.value = True # Do not open panel during presentation by on_load function, otherwise immediately open it
+                self.overlay_button.value = True # Do not open panel during presentation by on_load function, otherwise immediately open it
             
         elif url is None:
             _html = self.html('div',[
@@ -964,9 +1003,8 @@ class Slides:
                 citation_mode   = 'global',
                 center          = True, 
                 content_width   = '90%', 
-                footer_text     = 'IPySlides | <a style="color:blue;" href="https://github.com/massgh/ipyslides">github-link</a>', 
-                show_date       = True,
-                show_slideno    = True,
+                short_title     = 'IPySlides | <a style="color:blue;" href="https://github.com/massgh/ipyslides">github-link</a>', 
+                date            = 'today',
                 logo_src        = logo_svg, 
                 font_scale      = 1, 
                 text_font       = 'STIX Two Text', 
@@ -986,7 +1024,7 @@ class Slides:
         _private_instance.settings.set(
             citation_mode = dict(mode = citation_mode),
             layout        = dict(center = center, content_width = content_width),
-            footer        = dict(text = footer_text, show_date = show_date, show_slideno = show_slideno),
+            footer        = dict(text = short_title, date = date),
             logo          = dict(src = logo_src,width = 60),
             font_scale    = dict(font_scale = font_scale),
             font_family   = dict(text_font = text_font, code_font = code_font),
