@@ -1,9 +1,9 @@
-__all__ = ['alt','alert', 'color', 'bullets','suppress_output','suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
+_attrs = ['alt','alert', 'block', 'bullets', 'classed', 'color', 'cols','suppress_output','suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
             'image','svg','iframe', 'format_html','format_css','keep_format', 'run_doc',
-            'raw','enable_zoom','html','sig','doc','code','today','sub','sup']
-__all__.extend(['rows','cols','block','classed'])
-__all__.extend([f'block_{c}' for c in 'rgbycma'])
+            'raw', 'rows', 'enable_zoom','html','sig','doc','code','today','sub','sup']
 
+_attrs.extend([f'block_{c}' for c in 'red green blue cyan magenta yellow gray'.split()])
+__all__ = sorted(_attrs)
 
 import os, re
 import datetime
@@ -18,18 +18,27 @@ from IPython.core.display import Image, display
 from IPython.utils.capture import capture_output
 import ipywidgets as ipw
 
-from .formatters import fix_ipy_image, _HTML, _fix_repr
+from .formatters import XTML, fix_ipy_image, htmlize
 from .xmd import get_unique_css_class
+from .writer import Writer, AltForWidget
 
 def _fmt_cols(*objs,widths = None):
     if not widths and len(objs) >= 1:
         widths = [f'{int(100/len(objs))}%' for _ in objs]
     else:
-        widths = [f'{w}%' for w in widths]
+        if len(objs) != len(widths):
+            raise ValueError(f'Number of columns ({len(objs)}) and widths ({len(widths)}) do not match')
+        
+        for w in widths:
+            if not isinstance(w,(int, float)):
+                raise TypeError(f'widths must be numbers, got {w}')
+        widths = [int(w/sum(widths)*100) for w in widths]
+    
+    widths = [f'{w}%' for w in widths]
     
     _cols = [_c if isinstance(_c,(list,tuple)) else [_c] for _c in objs] 
     _cols = ' '.join([f"""<div style='width:{w};overflow-x:auto;height:auto'>
-                     {' '.join([_fix_repr(row) for row in _col])}
+                     {' '.join([htmlize(row) for row in _col])}
                      </div>""" for _col,w in zip(_cols,widths)])
     
     if len(objs) == 1:
@@ -183,7 +192,7 @@ def set_dir(path):
 
 def format_html(*objs,widths=None):
     'Format objects in columns, same was as write does, but with limited content types, provide in write function'
-    return _HTML(_fmt_cols(*objs,widths=widths))
+    return XTML(_fmt_cols(*objs,widths=widths))
 
 def _validate_key(key):
     "Validate key for CSS,allow only string or tuple of strings. commas are allowed only in :is(.A,#B),:has(.A,#B) etc."
@@ -260,29 +269,26 @@ def format_css(css_dict):
     "{css_docstring}"
     return _format_css(css_dict, allow_root_attrs = False)
 
-def alt(widget, obj):
-    "Display `widget` for slides and `obj` will be and displayed only in exported formats as HTML."
-    if not isinstance(widget, ipw.DOMWidget):
-        raise TypeError(f'widget should be a widget, got {widget!r}')
-    if isinstance(obj, ipw.DOMWidget):
-        raise TypeError(f'obj should not be a widget, got {obj!r}')
-    class Alt:
-        def __init__(self, widget, obj):
-            self._widget = widget
-            self._obj = obj
-            
-        def _ipython_display_(self):
-            return self.display()
-            
-        def display(self):
-            display(widget, metadata = {'DOMWidget': '---'})
-            display(_HTML(f'<div class="export-only">{_fix_repr(obj)}</div>')) # Hide from slides
-         
-    return Alt(widget, obj)
+def alt(widget, func):
+    """Display `widget` for slides and output of `func(widget)` will be and displayed only in exported formats as HTML.
+    `func` should return possible HTML representation (provided by user) of widget as string.
+    
+    ```python run source
+    import ipywidgets as ipw
+    slides = get_slides_instance()
+    slides.alt(ipw.IntSlider(),lambda w: f'<input type="range" min="{w.min}" max="{w.max}" value="{w.value}">').display()
+    ```
+    {{source}}
+    
+    ::: note-info
+        - If you happen to be using alt many times for same type, you can use `Slides.serializer.register` and then pass that type of widget without alt.
+        - You can also use `display(obj, metadata=`Slides.serializer.get_metadata(obj)` or `{'text/html':'html representation'}`) where obj is widget or any other object, but HTML representation will be oldest as given in metadata.
+    """
+    return AltForWidget(widget, func)
         
 def details(str_html,summary='Click to show content'):
     "Show/Hide Content in collapsed html."
-    return _HTML(f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{str_html}</details>""")
+    return XTML(f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{str_html}</details>""")
 
 def __check_pil_image(data):
     "Check if data is a PIL Image or numpy array"
@@ -304,9 +310,9 @@ def image(data=None,width='80%',caption=None, **kwargs):
     if isinstance(width,int):
         width = f'{width}px'
     _data = __check_pil_image(data) #Check if data is a PIL Image or return data
-    img = fix_ipy_image(Image(data = _data,**kwargs),width=width) # gievs _HTML object
+    img = fix_ipy_image(Image(data = _data,**kwargs),width=width) # gievs XTML object
     cap = f'<figcaption class="no-zoom">{caption}</figcaption>' if caption else ''
-    return html('figure', img.value + cap, className='zoom-child')  # Add caption,  _HTML + _HTML
+    return html('figure', img.value + cap, className='zoom-child')  # Add caption,  XTML + XTML
 
 def svg(data=None,caption=None,**kwargs):
     "Display svg file or svg string/bytes with additional customizations. `kwrags` are passed to IPython.display.SVG. You can provide url/string/bytes/filepath for svg."
@@ -318,7 +324,7 @@ def svg(data=None,caption=None,**kwargs):
 def iframe(src, width='100%',height='auto',**kwargs):
     "Display `src` in an iframe. `kwrags` are passed to IPython.display.IFrame"
     f = IFrame(src,width,height, **kwargs)
-    return _HTML(f._repr_html_())
+    return XTML(f._repr_html_())
 
 def enable_zoom(obj):
     "Wraps a given obj in a parent with 'zoom-child' class or add 'zoom-self' to widget, whether a widget or html/IPYthon object"
@@ -337,14 +343,14 @@ def classed(obj, className):
     if isinstance(obj,ipw.DOMWidget):
         return obj.add_class(className)
     else:
-        return _HTML(f'<div class="{className}">{_fix_repr(obj)}</div>')
+        return XTML(f'<div class="{className}">{htmlize(obj)}</div>')
 
 def center(obj):
     "Align a given object at center horizontally, whether a widget or html/IPYthon object"
     if isinstance(obj,ipw.DOMWidget):
         return ipw.Box([obj]).add_class('align-center') # needs to wrap in another for cenering
     else:
-        return _HTML(f'<div class="align-center">{_fix_repr(obj)}</div>')
+        return XTML(f'<div class="align-center">{htmlize(obj)}</div>')
     
 def html(tag, children = None,className = None,**node_attrs):
     """Returns html node with given children and node attributes like style, id etc. If an ttribute needs '-' in its name, replace it with '_'.     
@@ -361,7 +367,7 @@ def html(tag, children = None,className = None,**node_attrs):
     ```
     """
     if tag in 'hr/':
-        return _HTML(f'<hr/>') # Special case for hr
+        return XTML(f'<hr/>') # Special case for hr
     
     if children and tag.endswith('/'):
         raise RuntimeError(f'Parametr `children` should be None for self closing tag {tag!r}')
@@ -376,19 +382,19 @@ def html(tag, children = None,className = None,**node_attrs):
         attrs = f'class="{className}" {attrs}'
     
     if tag.endswith('/'): # Self closing tag
-        return _HTML(f'<{tag[:-1]} {attrs} />' if attrs else f'<{tag[:-1]}/>')
+        return XTML(f'<{tag[:-1]} {attrs} />' if attrs else f'<{tag[:-1]}/>')
     
     if children is None:
         content = ''
     elif isinstance(children,str):
         content = children
     elif isinstance(children,(list,tuple)):
-        content = '\n'.join(_fix_repr(child) for child in children) # Convert to html nodes in sequence of rows
+        content = '\n'.join(htmlize(child) for child in children) # Convert to html nodes in sequence of rows
     else:
         raise TypeError(f'Children should be a list/tuple of objects or str, not {type(children)}')
         
     tag_in =  f'<{tag} {attrs}>' if attrs else f'<{tag}>' # space is must after tag, strip attrs spaces
-    return _HTML(f'{tag_in}{content}</{tag}>')
+    return XTML(f'{tag_in}{content}</{tag}>')
 
 def vspace(em = 1):
     "Returns html node with given height in `em`."
@@ -400,27 +406,27 @@ def textbox(text, **css_props):
     css_props = {'display':'inline-block','white-space': 'pre', **css_props} # very important to apply text styles in order
     # white-space:pre preserves whitspacing, text will be viewed as written. 
     _style = ' '.join([f"{key.replace('_','-')}:{value};" for key,value in css_props.items()])
-    return _HTML(f"<span class='text-box' style = {_style!r}>{text}</span>")  # markdown="span" will avoid inner parsing
+    return XTML(f"<span class='text-box' style = {_style!r}>{text}</span>")  # markdown="span" will avoid inner parsing
 
 def alert(text):
     "Alerts text!"
-    return _HTML(f"<span style='color:#DC143C;'>{text}</span>")
+    return XTML(f"<span style='color:#DC143C;'>{text}</span>")
     
 def color(text,fg='blue',bg=None):
     "Colors text, `fg` and `bg` should be valid CSS colors"
-    return _HTML(f"<span style='background:{bg};color:{fg};padding: 0.1em;border-radius:0.1em;'>{text}</span>")
+    return XTML(f"<span style='background:{bg};color:{fg};padding: 0.1em;border-radius:0.1em;'>{text}</span>")
 
 def keep_format(plaintext_or_html):
     "Bypasses from being parsed by markdown parser. Useful for some graphs, e.g. keep_format(obj.to_html()) preserves its actual form."
     if not isinstance(plaintext_or_html,str):
         return plaintext_or_html # if not string, return as is
-    return _HTML(plaintext_or_html) 
+    return XTML(plaintext_or_html) 
 
 def raw(text, className=None): # className is required here
     "Keep shape of text as it is (but apply dedent), preserving whitespaces as well. "
     _class = className if className else ''
     escaped_text = escape(textwrap.dedent(text).strip('\n')) # dedent and strip newlines on top and bottom
-    return _HTML(f"<div class='raw-text {_class}'>{escaped_text}</div>")
+    return XTML(f"<div class='raw-text {_class}'>{escaped_text}</div>")
 
 def rows(*objs):
     "Returns tuple of objects. Use in `write` for better readiability of writing rows in a column."
@@ -430,21 +436,47 @@ def cols(*objs,widths=None):
     "Returns HTML containing multiple columns of given widths."
     return format_html(*objs,widths=widths)
 
-def block(*objs,className = 'block'):
-    """Format a block like in LATEX beamer. *objs expect to be a subset of writables with `write` command.   
-    ::: block
-        - Shortcut functions with pre-specified background colors are available: `block_<r,g,b,y,c,m,a>`.
-        - You can create blocks just by CSS classes in markdown as {.block}, {.block-red}, {.block-green}, etc.
-    """
-    return _HTML(f"<div class='{className}'>{_fmt_cols(objs)}</div>")
+def _block(*objs, widths = None, suffix = ''): # suffix is for block-{suffix} class
+    if len(objs) == 0:
+        return # Nothing
     
-def block_r(*objs): return block(*objs,className = 'block-red')
-def block_b(*objs): return block(*objs,className = 'block-blue')
-def block_g(*objs): return block(*objs,className = 'block-green')
-def block_y(*objs): return block(*objs,className = 'block-yellow')
-def block_c(*objs): return block(*objs,className = 'block-cyan')
-def block_m(*objs): return block(*objs,className = 'block-magenta')
-def block_a(*objs): return block(*objs,className = 'block-gray')
+    if suffix and suffix not in 'red green blue yellow cyan magenta gray'.split():
+        raise ValueError(f'Invalid suffix {suffix!r}, should be one of [red, green, blue, yellow, cyan, magenta, gray]')
+    
+    make_grid = False # If only one object, make it grid to remove extra gap
+    if len(objs) == 1:
+        make_grid = True
+        objs = ['',objs[0],''] # Add empty strings to make it three columns and center it, otherwise it will not work as block
+        widths = [1,98,1] # 1% width for empty strings and make content central
+    
+    wr = Writer(*objs,widths = widths) # Displayed
+    wr._box.add_class('block' + (f'-{suffix}' if suffix else '')) # Add class to box
+    if make_grid:
+        wr._box.layout.display = 'grid' # Make it grid
+        wr._box.layout.grid_gap = '1em 0px' # Remove extra gap in columns, but keep row gap
+        wr._extra_style = 'style="display:grid;grid-gap:1em 0px;"' # Add extra style to box for fmt_html to use
+        
+    if not any([(wr._slides and wr._slides.running), wr._in_proxy]):
+        return wr.update_display() # Update in usual cell to have widgets working
+    
+def block(*objs, widths = None): 
+    """
+    Format a block like in LATEX beamer with `objs` in columns and immediately display it. Format rows by given an obj as list of objects.   
+    ::: block
+        - Block is automatically displayed and returns nothing.
+        - Available functions include: `block_<red,green,blue,yellow,cyan,magenta,gray>`.
+        - You can create blocks just by CSS classes in markdown as {.block}, {.block-red}, {.block-green}, etc.
+        - See documentation of `write` command for details of `objs` and `widths`.
+    """
+    return _block(*objs, widths = widths)  
+
+def block_red(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'red')
+def block_blue(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'blue')
+def block_green(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'green')
+def block_yellow(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'yellow')
+def block_cyan(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'cyan')
+def block_magenta(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'magenta')
+def block_gray(*objs, widths = None): return _block(*objs, widths = widths, suffix = 'gray')
 
 def sig(callable,prepend_str = None):
     "Returns signature of a callable. You can prepend a class/module name."
@@ -452,7 +484,7 @@ def sig(callable,prepend_str = None):
         _sig = f'<b>{callable.__name__}</b><span style="font-size:85%;color:var(--secondary-fg);">{str(inspect.signature(callable))}</span>'
         if prepend_str: 
             _sig = f'{color(prepend_str,"var(--accent-color)")}.{_sig}' # must be inside format string
-        return _HTML(_sig)
+        return XTML(_sig)
     except:
         raise TypeError(f'Object {callable} is not a callable')
 
@@ -460,12 +492,12 @@ def sig(callable,prepend_str = None):
 def doc(obj,prepend_str = None, members = None, itself = True):
     "Returns documentation of an `obj`. You can prepend a class/module name. members is True/List of attributes to show doc of."
     if obj is None:
-        return _HTML('') # Must be _HTML to work on memebers
+        return XTML('') # Must be XTML to work on memebers
     
     _doc, _sig, _full_doc = '', '', ''
     if itself == True:
         with suppress(BaseException): # if not __doc__, go forwards
-            _doc += _fix_repr((inspect.getdoc(obj) or '').replace('{','\u2774').replace('}','\u2775'))
+            _doc += htmlize((inspect.getdoc(obj) or '').replace('{','\u2774').replace('}','\u2775'))
 
         with suppress(BaseException): # This allows to get docs of module without signature
             _sig = sig(obj,prepend_str)
@@ -478,7 +510,7 @@ def doc(obj,prepend_str = None, members = None, itself = True):
     _pstr = f'{str(prepend_str) + "." if prepend_str else ""}{_name}'
     
     if _name.startswith('_'): # Remove private attributes
-        return _HTML('') # Must be _HTML to work on memebers
+        return XTML('') # Must be XTML to work on memebers
     
     _sig = _sig or color(_pstr,"var(--accent-color)") # Picks previous signature if exists
     _full_doc = f"<div class='docs'>{_sig}<br>{_doc}\n</div>" if itself == True else ''
@@ -514,7 +546,7 @@ def doc(obj,prepend_str = None, members = None, itself = True):
             _class_members = inspect.ismodule(obj) and (inspect.isclass(attr) and (attr.__module__ == obj.__name__)) # Restrict imported classes in docs
             _full_doc += doc(attr, prepend_str = _pstr, members = _class_members, itself = True).value
     
-    return _HTML(_full_doc)
+    return XTML(_full_doc)
 
 def run_doc(obj,prepend_str = None):
     "Execute python code block inside docstring of an object. Block should start with '\`\`\`python run'."
@@ -525,7 +557,7 @@ def run_doc(obj,prepend_str = None):
 def code(callable):
     "Returns full code of a callable, you can just pass callable into `write` command or use `ipyslides.Slides().source.from_callable`."
     try:
-        return _HTML(_fix_repr(callable))
+        return XTML(htmlize(callable))
     except:
         raise TypeError(f'Object {callable} is not a callable')
 
