@@ -2,15 +2,89 @@
 Main write functions to add content to slides
 """
 
-__all__ = ['write', 'iwrite']
+__all__ = ['write']
 
 import ipywidgets as ipw
 from IPython.display import display as display
 from IPython.utils.capture import capture_output
 
-from .formatters import _HTML, _HTML_Widget, stringify, _fix_repr
+from .formatters import XTML, htmlize, serializer
 from .xmd import parse, get_slides_instance
 
+class CustomDisplay:
+    def _ipython_display_(self):
+        return self.display()
+    
+    def display(self):
+        raise NotImplementedError("display method must be implemented in subclass")
+    
+class GotoButton(CustomDisplay):
+    "Should not be used directly, use `Slides.goto_button` instead."
+    def __init__(self, button, app):
+        self._button = button
+        self._app = app
+        self._button._TargetSlide = None # Will be set by set_target
+        self._target_id = f't-{id(button)}'
+    
+    def __repr__(self) -> str:
+        return '<GotoButton>'
+    
+    def display(self):
+        alt_link = self._app.html('a',self._button.description, href=f'#{self._target_id}', 
+            style='color:var(--accent-color);text-decoration:none;', 
+            className='goto-button slides-only export-only'
+        )
+    
+        display(self._button, metadata = {'DOMWidget': '---'})
+        display(alt_link) # Hidden from slides
+        
+    def set_target(self, force = False):
+        if not self._app.running:
+            raise RuntimeError("GotoButton's target can be set only inside a slide constructor!")
+        if self._button._TargetSlide and not force:
+            raise RuntimeError("GotoButton's target can be set only once! Use `force=True` to link here and remove previous link.")
+        
+        if force:
+            self._button._TargetSlide._target_id = None # Remove previous link
+        
+        self._button._TargetSlide = self._app.running
+        self._button._TargetSlide._target_id = self._target_id # Set new link
+    
+class AltForWidget(CustomDisplay):
+    def __init__(self, widget, func):
+        if not isinstance(widget, ipw.DOMWidget):
+            raise TypeError(f'widget should be a widget, got {widget!r}')
+        if not callable(func):
+            raise TypeError(f'func should be a callable, got {func!r}')
+        self._widget = widget
+        self._func = func
+        
+        slides = get_slides_instance()
+        if slides: 
+            with slides._hold_running(): # To prevent dynamic content from being added to alt
+                with capture_output() as cap:
+                    out = self._func(self._widget)
+                    if not isinstance(out, str):
+                        raise TypeError(f'Function {func.__name__!r} should return a string, got {type(out)}')
+                if cap.stderr:
+                    raise RuntimeError(f'Function {func.__name__!r} raised an error: {cap.stderr}')
+
+                if cap.outputs: # This also makes sure no dynamic content is inside alt, as nested contnet cannot be refreshed
+                    raise RuntimeError(f'Function {func.__name__!r} should not display or print anything in its body, it should return a string.')   
+        
+    def __repr__(self):
+        return 'AltForWidget(widget, func)'
+        
+    def _ipython_display_(self):
+        return self.display()
+        
+    def display(self):
+        slides = get_slides_instance()
+        if slides and (context := (slides.in_proxy or slides.running)):
+            display(context._exp4widget(self._widget, self._func))
+        else:
+            display(self._widget, metadata = {'DOMWidget': '---'}) # Display widget under slides/notebook anywhere
+
 class Writer:
     _in_write = False # To prevent write from being called inside write
     def __init__(self,*objs,widths = None):
@@ -28,8 +102,9 @@ class Writer:
             self.__class__._in_write = False
             
         self._slide = self._slides.running if self._slides else None
-        self._in_proxy = getattr(self._slides, '_in_proxy', None)
+        self._in_proxy = getattr(self._slides, '_in_proxy', None) # slide itself can be Non, so get via getattr
         self._in_dproxy = getattr(self._slides, '_in_dproxy', None)
+        self._context = (self._in_dproxy if self._in_dproxy else self._slide) or self._in_proxy # order strictly matters
         
         if len(objs) == 1:
             display(*self._cols[0]['outputs']) # If only one column, display it directly
@@ -44,13 +119,16 @@ class Writer:
                 
     def _capture_objs(self, *objs, widths = None):
         if widths is None: # len(objs) check is done in write
-            widths = [100/len(objs) for _ in objs]
+            widths = [int(100/len(objs)) for _ in objs]
+        else:
+            if len(objs) != len(widths):
+                raise ValueError(f'Number of columns ({len(objs)}) and widths ({len(widths)}) do not match')
+        
+            for w in widths:
+                if not isinstance(w,(int, float)):
+                    raise TypeError(f'widths must be numbers, got {w}')
+            widths = [int(w/sum(widths)*100) for w in widths]
         
-        if len(objs) != len(widths):
-            raise ValueError(f'Number of columns ({len(objs)}) and widths ({len(widths)}) do not match')
-        for w in widths:
-            if not isinstance(w,(int, float)):
-                raise TypeError(f'widths must be numbers, got {w}')
         
         widths = [f'{int(w)}%' for w in widths]
         cols = [{'width':w,'outputs':_c if isinstance(_c,(list,tuple)) else [_c]} for w,_c in zip(widths,objs)]
@@ -59,16 +137,20 @@ class Writer:
                 for c in col['outputs']:
                     if isinstance(c,str):
                         parse(c, display_inline = True, rich_outputs = False)
+                    elif isinstance(c, CustomDisplay):
+                        c.display() # Handles all custom display classes like alt, goto_button etc.
                     elif callable(c) and c.__name__ == '<lambda>':
                         _ = c() # If c is a lambda function, call it and it will dispatch whatever is inside, ignore output
                     elif isinstance(c, ipw.DOMWidget): # Should be a displayable widget, not just Widget
-                        if self._slides and self._slides.running and isinstance(c, ipw.HTML):
-                            self._slides.alt(c, c.value).display() # Display HTML widget as slide and its value as hidden HTML
-                            # NOTE: This is enough, Do not go too deep like in boxes to search for HTML, because then we will lose the column structure
+                        if self._slides and self._slides.running:
+                            if (func := serializer.get_func(c)):
+                                self._slides.alt(c, func).display() # Alternative representation will be available on export, specially for ipw.HTML
+                            else:
+                                display(c, metadata = {'DOMWidget': '---'}) # Display only widget
                         else:
                             display(c, metadata = {'DOMWidget': '---'}) # Display only widget outside slide buuilder
                     else:
-                        display(_HTML(stringify(c)))
+                        display(XTML(htmlize(c)))
             
             if cap.stderr:
                 raise RuntimeError(f'Error in column {i+1}:\n{cap.stderr}')
@@ -97,22 +179,32 @@ class Writer:
     @property
     def metadata(self): return {} # Required for check in slide display of there are widgets
     
-    def fmt_html(self, allow_non_html_repr = True):
+    def fmt_html(self):
         "Make HTML representation of columns that is required for exporting slides to other formats."
         cols = []
         for col in self._cols:
             content = ''
             for out in col['outputs']:
-                if hasattr(out, 'metadata') and 'DYNAMIC' in out.metadata: # Buried in column
-                    dpx = self._slide._dproxies[out.metadata['DYNAMIC']] # _slide is for sure there if dynamic proxy is there
-                    content += ('\n' + dpx.fmt_html(allow_non_html_repr = allow_non_html_repr))
+                if hasattr(out, 'metadata') and 'Exp4Widget' in out.metadata:
+                    epx = self._context._exportables[out.metadata['Exp4Widget']]
+                    content += ('\n' + epx.fmt_html() + '\n') # rows should be on their own line
+                elif hasattr(out, 'metadata') and 'DYNAMIC' in out.metadata: # Buried in column
+                    dpx = self._context._dproxies[out.metadata['DYNAMIC']] 
+                    content += ('\n' + dpx.fmt_html())
+                elif 'Proxy' in out.metadata:
+                    px = self._context._proxies[out.metadata['Proxy']]
+                    content += ('\n' + px.fmt_html())
+                elif hasattr(out, 'metadata') and isinstance(out.metadata, dict) and 'text/html' in out.metadata: # Should take precedence over data if given
+                    content += ('\n' + out.metadata['text/html'])
                 elif 'text/html' in out.data:
                     content += ('\n' + out.data['text/html']) # rows should be on their own line
-                elif allow_non_html_repr:
-                    content += ('\n' + out.data['text/plain'])
         
             cols.append(f'<div style="width:{col["width"]};overflow:auto;height:auto">{content}</div>')
-        return f'<div class="columns">{"".join(cols)}</div>'
+        
+        className = ' '.join(self._box._dom_classes) # handle custom classes in blocks as well
+        style = getattr(self._box, '_extra_style', '') # provided from blocks
+        return f'<div class="{className}" {style}>{"".join(cols)}</div>'
+    
     
 def write(*objs,widths = None):
     """
@@ -126,122 +218,24 @@ def write(*objs,widths = None):
     - Dispaly IPython widgets such as `ipywidgets` or `ipyvolume` by passing them directly.
     - Display Axes/Figure form libraries such as `matplotlib`, `plotly` `altair`, `bokeh`, `ipyvolume` ect. by passing them directly.
     - Display source code of functions/classes/modules or other languages by passing them directly or using `Slides.source` API.
-    - Use `Slides.alt(widget, obj)` function to display widget on slides and alternative content in exported slides/report.
-    - `ipywidgets.HTML` and its subclasses will be displayed as `Slides.alt(widget, value)`. The value of exported HTML will be oldest one.
+    - Use `Slides.alt(widget, func)` function to display widget on slides and alternative content in exported slides/report, function should return possible HTML representation of widget.
+    - `ipywidgets.HTML` and its subclasses will be displayed as `Slides.alt(widget, html_converter_func)`. The value of exported HTML will be most recent.
     - Other options include but not limited to:
         - Output of functions in `ipyslides.utils` module that are also linked to `Slides` object.
         - PIL images, SVGs etc.
         - IPython display objects such as Image, SVG, HTML, Audio, Video, YouTubeVideo, IFrame, Latex, Markdown, JSON, Javascript, etc.
         - Any object that has a `_repr_html_` method, you can create one for your own objects/third party objects by:
-            - `Slides.serializer` API.
+            - `Slides.serializer` API. Use its `.get_metadata` method to display object as it is and export its HTML representation from metadata when used as `display(obj, metadata = {'text/html': 'html repr by user or by serializer.get_metadata(obj)'})`.
             - `IPython.core.formatters` API for third party libraries.
             
     ::: note
         - `write` is a robust command that can handle most of the cases. If nothing works, `repr(obj)` will be displayed.
         - You can avoid `repr(obj)` by `lambda: func()` e.g. `lambda: plt.show()`.
+        - You can use `display(obj, metadata = {'text/html': 'html repr by user'})` for any object to display object as it is and export its HTML representation in metadata.
         - A single string passed to `write` is equivalent to `parse` command.
+        - You can add mini columns inside a column by markdown syntax or `Slides.cols`, but content type is limited in that case.
     """
     wr = Writer(*objs,widths = widths)
     if not any([(wr._slides and wr._slides.running), wr._in_proxy]):
         return wr.update_display() # Update in usual cell to have widgets working
-    
 
-# We can just discourage the use of `iwrite` command in favor of the robust `write` command.        
-
-def _fmt_iwrite(*objs,widths=None):
-    if not widths:
-        widths = [f'{int(100/len(objs))}%' for _ in objs]
-    else:
-        widths = [f'{w}%' for w in widths]
-        
-    _cols = [_c if isinstance(_c,(list,tuple)) else [_c] for _c in objs] #Make list if single element
-    
-    # Conver to other objects to HTML
-    fixed_cols = []
-    for j, _rows in enumerate(_cols):
-        row = []
-        for i, item in enumerate(_rows):
-            if isinstance(item, ipw.DOMWidget):
-                item._grid_location = {'row':i,'column':j}
-                row.append(item)
-            else:
-                tmp = _HTML_Widget(value = _fix_repr(item))
-                if '</script>' in tmp.value:
-                    tmp.value = f'Error displaying object, cannot update object {item!r} as it needs Javascript. Use `write` or `display` commands or `ipywidgets.Outpt()` to display it.'
-
-                tmp._grid_location = {'row':i,'column':j}
-                row = [*row,tmp]
-        
-        fixed_cols.append(row)
-
-    children = [ipw.VBox(children = _c, layout = ipw.Layout(width=f'{_w}')) for _c, _w in zip(fixed_cols,widths)]
-    # Format things as given in input
-    out_cols = tuple(tuple(row) if len(row) > 1 else row[0] for row in fixed_cols) # If single element in row, unwrap it
-    out_cols = tuple(out_cols) # Each column is a tuple of rows even if it has only one row
-    return ipw.HBox(children = children).add_class('columns'), out_cols #Return display widget and list of objects for later use
-
-class _WidgetsWriter:
-    def __init__(self, *objs, widths=None):
-        self._grid, self._cols = _fmt_iwrite(*objs,widths=widths)
-        self._grid.add_class('columns')
-        if slides := get_slides_instance():
-            if slides.running: # slides assigment above works in below block only
-                slides._warnings.append('`iwrite` command will be deprecated. Use `write` command instead that wites widgets as well and handles a lot of formats for exporting to static html.')
-        
-    def _ipython_display_(self):
-        return display(self._grid)
-        
-    def __getitem__(self, index): # For unpacking like write, *objs
-        if index == 0:
-            return self
-        elif isinstance(index, int) and index != 0: # != 0 for accessing from -1, -2 as well
-            idx = index - 1 if index > 0 else index
-            return self._cols[idx]
-        else:
-            raise TypeError(f'Index should be integer, got {index!r}')
-    @property
-    def cols(self):
-        "Access columns of the grid. Each column is a list of widgets or single widget if only one row."
-        return self._cols
-    
-    def update(self, old_obj, new_obj):
-        "Updates `old_obj`  with `new_obj`. Returns reference to created/given widget, which can be updated by it's own methods."
-        row, col = old_obj._grid_location['row'], old_obj._grid_location['column']
-        widgets_row = list(self._grid.children[col].children)
-        
-        if isinstance(new_obj, ipw.DOMWidget):
-            tmp = new_obj
-        else:
-            tmp = _HTML_Widget(value = _fix_repr(new_obj))
-            if '</script>' in tmp.value:
-                tmp.value = f'Error displaying object, cannot update object {new_obj!r} as it needs Javascript. Use `write` or `display` commands or `ipywidgets.Outpt()` to display it.'
-                return # Don't update
-        
-        tmp._grid_location = old_obj._grid_location # Keep location
-        widgets_row[row] = tmp
-        self._grid.children[col].children = widgets_row
-        return tmp
-    
-def iwrite(*objs,widths = None):
-    """Each obj in objs could be an IPython widget like `ipywidgets`,`bqplots` etc 
-    or list/tuple (or wrapped in `rows` function) of widgets to display as rows in a column. 
-    Other objects (those in `write` command) will be converted to HTML widgets if possible. 
-    Object containing javascript code may not work, use `write` command for that.
-    
-    Get a list of already available classes using `slides.css_styles`. For these you dont need to provide CSS.
-    
-    **Returns**: writer, objs as reference to use later and update. rows are packed in columns.
-    
-    **Examples**:
-    ```python
-    writer, x = iwrite('X')  # writer = iwrite('X'); x = writer.cols[0] # gives same result
-    writer, (x,y) = iwrite('X','Y')
-    writer, (x,y) = iwrite(['X','Y']) # One column with two rows
-    writer, (x,y),z = iwrite(['X','Y'],'Z')
-    #We unpacked such a way that we can replace objects with new one using `grid.update`
-    new_obj = writer.update(x, 'First column, first row with new data') #You can update same `new_obj` with it's own widget methods. 
-    ```
-    """
-    wr = _WidgetsWriter(*objs,widths=widths)
-    display(wr._grid, metadata = {'DOMWidget':'---'}) # Display it must to show it there with a metadata
-    return wr # Return it to use later as writer, columns unpacked
\ No newline at end of file
